@@ -11,7 +11,7 @@ app.register.controller('ClientsMonitoring', ['$scope', '$filter', 'gridCrudServ
             translate("clients_ip"), translate("clients_vlan"), translate("clients_poe")
         ];
         var showCDPDetails;
-        var showLldpDeatils;
+        var showLldpDetails;
         format_attributes= function(showLldpDetails) {
              for(var i=0;i<showLldpDetails.length;i++){
                  if(showLldpDetails[i].Capabilities.indexOf("T") != -1){
@@ -32,13 +32,13 @@ app.register.controller('ClientsMonitoring', ['$scope', '$filter', 'gridCrudServ
         remove_duplicates = function(showCDPDetails, showLldpDetails) {
 			for (var i in showCDPDetails) {
                  for (var j in showLldpDetails) {
-                      if(showLldpDetails[j].ClientName == showCDPDetails[i].ClientName){
+                      if(showLldpDetails[j].ClientName == showCDPDetails[i].ClientName || showLldpDetails[j].SwitchPort == showCDPDetails[i].SwitchPort){
                          showLldpDetails.splice(j, 1);
                          break;
                       }
                  }
             }
-             if (typeof showLldpDetails == "object") {
+            if (typeof showLldpDetails == "object") {
             	  if(showLldpDetails!="")
                     showCDPDetails = showCDPDetails.concat(showLldpDetails);
             }
@@ -46,12 +46,21 @@ app.register.controller('ClientsMonitoring', ['$scope', '$filter', 'gridCrudServ
         }
         $scope.showCDP = function(){
         	showCDPDetails = requestRoutingService.getShowCmdOutput("show cdp neighbors detail", "clientsShowCdpNeighborsDetail");
-            showCDPDetails = showCDPDetails.showCdpNeighborsDetail.wnwebdata;
-			var showCDPDetailsDummy = showCDPDetails;
+            if(angular.isUndefined(showCDPDetails.showCdpNeighborsDetail.wnwebdata)){
+                showCDPDetails = undefined;
+            }else if(!angular.isArray(showCDPDetails.showCdpNeighborsDetail.wnwebdata)){
+                showCDPDetails = [showCDPDetails.showCdpNeighborsDetail.wnwebdata];
+            }else{
+                showCDPDetails = showCDPDetails.showCdpNeighborsDetail.wnwebdata;
+            }
+            var showCDPDetailsDummy = showCDPDetails;
             showLldpDetails = requestRoutingService.getShowCmdOutput("show lldp neighbors detail", "clientsShowLldpNeighborsDetail");
-            showLldpDetails = showLldpDetails.showLldpNeighborsDetail.wnwebdata;
-            if (typeof showLldpDetails == "object" && !showLldpDetails.length){				
-                showLldpDetails = [showLldpDetails];
+            if(angular.isUndefined(showLldpDetails.showLldpNeighborsDetail.wnwebdata)){
+                showLldpDetails = undefined;
+            }else if(!angular.isArray(showLldpDetails.showLldpNeighborsDetail.wnwebdata)){
+                showLldpDetails = [showLldpDetails.showLldpNeighborsDetail.wnwebdata];
+            }else{
+                showLldpDetails = showLldpDetails.showLldpNeighborsDetail.wnwebdata;
             }
             if(showLldpDetails==undefined){
             	showLldpDetails = [];
@@ -78,9 +87,6 @@ app.register.controller('ClientsMonitoring', ['$scope', '$filter', 'gridCrudServ
                 showCDPDetails = showLldpDetails;
             } else {
                showCDPDetails =  remove_duplicates(showCDPDetails, showLldpDetails);
-            }
-			if (typeof showCDPDetails == "object" && !showCDPDetails.length){
-                showCDPDetails = [showCDPDetails];
             }
 			showCDPDetails = $filter("filter")(showCDPDetails);
             var showDeviceClassifier =requestRoutingService.getShowCmdOutput("show device classifier attached", "clientsShowDeviceClassifierAttached");
@@ -93,8 +99,7 @@ app.register.controller('ClientsMonitoring', ['$scope', '$filter', 'gridCrudServ
                 showDeviceClassifier.pop();
                 showDeviceClassifier.shift();
                 showDeviceClassifier = $filter("filter")(showDeviceClassifier);
-            }
-            else{
+            } else{
                 showDeviceClassifier = showDeviceClassifier[0].showDeviceClassifierAttached.wnwebdata;
             }
             for (var i in showCDPDetails) {
@@ -146,19 +151,21 @@ app.register.controller('ClientsMonitoring', ['$scope', '$filter', 'gridCrudServ
             }
             var deviceInterface1=null;
             for (var i in showDeviceClassifier) {
-            	if(showDeviceClassifier[i].Manufacturer.indexOf("APPLE")!=-1){
-            		showCDPDetails[appleClient]={};
-	            	showCDPDetails[appleClient].MAC = showDeviceClassifier[i].MAC;
-	            	deviceInterface1=showDeviceClassifier[i].SwitchPort;
-                	showCDPDetails[appleClient].SwitchPort = deviceInterface1;
-	            	showCDPDetails[appleClient].ClientName = showDeviceClassifier[i].ClientName;
-	            	showCDPDetails[appleClient].OS = "";
-	            	showCDPDetails[appleClient].Manufacturer = showDeviceClassifier[i].Manufacturer;
-	            	showCDPDetails[appleClient].IP = "";
-	            	showCDPDetails[appleClient].VLAN = "";
-	            	showCDPDetails[appleClient].PoEDrawn = "";
-	            	showCDPDetails[appleClient].Images = "/resources/images/apple-device.png";
-	            	appleClient++;
+            	if(showDeviceClassifier[i].hasOwnProperty("Manufacturer")){
+	            	if(showDeviceClassifier[i].Manufacturer.indexOf("APPLE")!=-1){
+	            		showCDPDetails[appleClient]={};
+		            	showCDPDetails[appleClient].MAC = showDeviceClassifier[i].MAC;
+		            	deviceInterface1=showDeviceClassifier[i].SwitchPort;
+	                	showCDPDetails[appleClient].SwitchPort = deviceInterface1;
+		            	showCDPDetails[appleClient].ClientName = showDeviceClassifier[i].ClientName;
+		            	showCDPDetails[appleClient].OS = "";
+		            	showCDPDetails[appleClient].Manufacturer = showDeviceClassifier[i].Manufacturer;
+		            	showCDPDetails[appleClient].IP = "";
+		            	showCDPDetails[appleClient].VLAN = "";
+		            	showCDPDetails[appleClient].PoEDrawn = "";
+		            	showCDPDetails[appleClient].Images = "/resources/images/apple-device.png";
+		            	appleClient++;
+	            	}
             	}
             }
             showCDPDetails = appleCheck(showCDPDetails, showDeviceClassifier);
