@@ -142,14 +142,6 @@ function($scope,dayZeroStepService, validationService, $timeout, $filter,request
 			});
 		}
 	}
-	for(var i3=0;i3<teInterface.length;i3++){
-		if(teInterface[i3].Interface.indexOf("Loopback")==-1){
-			teInterfaceNames.push({
-				"uplinkPortText": teInterface[i3].Interface,
-				"uplinkPortValue": teInterface[i3].Interface
-			});
-		}
-	}
 	vlanInterface=ports.filter(function (el) {
 		return (el.Interface=='Vlan1');
 	});
